aboutsummaryrefslogtreecommitdiffstats
path: root/engine/menus
diff options
context:
space:
mode:
authorAsh Ketchum <no-reply@sl0p.foo>2026-07-15 01:12:25 +0200
committerAsh Ketchum <no-reply@sl0p.foo>2026-07-15 01:12:25 +0200
commitd5c0f1ab2a04279fd973f4bd8bad5cfbd210f1ad (patch)
tree815b09b9e3d8a286fa548ef437d9ae93b0efb2ed /engine/menus
parentwarp: center the menu box and add a SECRET SL0P WARP MENU banner (diff)
downloadpokeyellow-d5c0f1ab2a04279fd973f4bd8bad5cfbd210f1ad.tar.gz
pokeyellow-d5c0f1ab2a04279fd973f4bd8bad5cfbd210f1ad.tar.xz
pokeyellow-d5c0f1ab2a04279fd973f4bd8bad5cfbd210f1ad.zip
intro: brief POKeMON SL0P EDITION splash on the fastboot path
New SlopSplash (engine/slop_intro.asm) clears the screen, draws the two centered lines, pushes to VRAM and holds ~2s, then MainMenu's autoload continues into the game. Replaces the vanilla intro/title for the fast-boot-into-save flow.
Diffstat (limited to 'engine/menus')
-rw-r--r--engine/menus/main_menu.asm7
1 files changed, 5 insertions, 2 deletions
diff --git a/engine/menus/main_menu.asm b/engine/menus/main_menu.asm
index c41a7d10..2875290e 100644
--- a/engine/menus/main_menu.asm
+++ b/engine/menus/main_menu.asm
@@ -10,10 +10,13 @@ MainMenu:
predef TryLoadSaveFile
; FASTBOOT: if the save loaded cleanly (status 2), skip the menu and continue
ld a, [wSaveFileStatus]
cp 2
- jp z, SpecialEnterMap
+ jr nz, .mainMenuLoop
+ farcall SlopSplash
+ jp SpecialEnterMap
.mainMenuLoop
ld c, 20
@@ -10,10 +10,13 @@ MainMenu:
predef TryLoadSaveFile
-; FASTBOOT: if the save loaded cleanly (status 2), skip the menu and continue
+; FASTBOOT: if the save loaded cleanly (status 2), show the SL0P splash then
+; skip the menu and continue straight into the game
ld a, [wSaveFileStatus]
cp 2